package com.phm.manage.mapper;

import com.phm.manage.domain.Product;

import java.util.List;

/**
 * 产品树信息Mapper接口
 *
 * @author phm
 * @date 2023-08-31
 */
public interface ProductMapper {
    /**
     * 查询产品树信息
     *
     * @param id 产品树信息主键
     * @return 产品树信息
     */
    public Product selectProductById(Long id);

    /**
     * 查询产品树信息列表
     *
     * @param product 产品树信息
     * @return 产品树信息集合
     */
    public List<Product> selectProductList(Product product);

    /**
     * 新增产品树信息
     *
     * @param product 产品树信息
     * @return 结果
     */
    public int insertProduct(Product product);

    /**
     * 修改产品树信息
     *
     * @param product 产品树信息
     * @return 结果
     */
    public int updateProduct(Product product);

    /**
     * 删除产品树信息
     *
     * @param id 产品树信息主键
     * @return 结果
     */
    public int deleteProductById(Long id);

    /**
     * 批量删除产品树信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProductByIds(Long[] ids);
}
